pub struct AppInvokeRequest {
pub app: String,
pub operation: String,
pub params: Option<Map<String, Value>>,
pub connection: String,
pub instance: String,
pub idempotency_key: String,
pub credential_mode: String,
pub context: Option<RequestContext>,
pub run_as: Option<SubjectContext>,
pub headers: BTreeMap<String, String>,
}Expand description
AppInvokeRequest invokes a declared operation on another app through Gestalt.
Native message type for gestalt.provider.v1.AppInvokeRequest.
Fields
app: StringThe app field.
operation: StringThe operation field.
params: Option<Map<String, Value>>The params field; None when unset.
connection: StringThe connection field.
instance: StringThe instance field.
idempotency_key: StringThe idempotency_key field.
credential_mode: StringThe credential_mode field.
context: Option<RequestContext>The context field; None when unset.
run_as: Option<SubjectContext>The run_as field; None when unset.
headers: BTreeMap<String, String>headers overrides outbound static headers declared by the target provider.
The headers field.