pub struct InvokeMetadata {
pub status: i32,
pub headers: BTreeMap<String, StringList>,
pub media_type: String,
}Expand description
InvokeMetadata is the first frame of a streaming invocation. It carries the HTTP-shaped status, headers, and the response media type (from the operation’s StreamResponseSpec).
Native message type for gestalt.provider.v1.InvokeMetadata.
Fields
status: i32The status field.
headers: BTreeMap<String, StringList>The headers field.
media_type: StringThe media_type field.