pub struct ProviderContext {
pub kind: String,
pub name: String,
}Expand description
ProviderContext identifies the provider process that received the request context from the host and is trusted to propagate it back to host services.
Native message type for gestalt.provider.v1.ProviderContext.
Fields
kind: StringThe kind field.
name: StringThe name field.