pub struct ResolveHTTPSubjectResponse {
pub subject: Option<SubjectContext>,
pub reject_status: i32,
pub reject_message: String,
}Expand description
ResolveHTTPSubjectResponse returns the concrete Gestalt subject a hosted HTTP request should execute as. An unset subject means “fall back to the binding subject”. When reject_status is set, the host should reject the inbound request with the provided status and message.
Native message type for gestalt.provider.v1.ResolveHTTPSubjectResponse.
Fields
subject: Option<SubjectContext>The subject field; None when unset.
reject_status: i32The reject_status field.
reject_message: StringThe reject_message field.