pub fn current_native_request_context() -> Option<RequestContext>
Returns the current ambient request context in the generated clients’ native form, for with_context on contextful clients such as App, Agent, and Workflow.
with_context
App
Agent
Workflow