pub enum CursorDirection {
Next,
NextUnique,
Prev,
PrevUnique,
}Expand description
Controls cursor traversal order.
Variants
Next
Iterate in ascending key order.
NextUnique
Iterate in ascending key order while collapsing duplicate index keys.
Prev
Iterate in descending key order.
PrevUnique
Iterate in descending key order while collapsing duplicate index keys.