pub struct TransactionCommitResponse {
pub error: Option<RpcStatus>,
}Expand description
TransactionCommitResponse carries a non-OK status when commit failed after the provider accepted the commit frame and rolled the transaction back.
Native message type for gestalt.provider.v1.TransactionCommitResponse.
Fields
error: Option<RpcStatus>The error field; None when unset.