pub struct TransactionIndexClient<'a> { /* private fields */ }Expand description
Secondary-index operations scoped to an explicit transaction.
Implementations
Sourceimpl TransactionIndexClient<'_>
impl TransactionIndexClient<'_>
Sourcepub async fn get(&mut self, values: &[Value]) -> Result<Record, IndexedDBError>
pub async fn get(&mut self, values: &[Value]) -> Result<Record, IndexedDBError>
Loads the first row that matches values inside the transaction.
Sourcepub async fn get_key(
&mut self,
values: &[Value],
) -> Result<String, IndexedDBError>
pub async fn get_key( &mut self, values: &[Value], ) -> Result<String, IndexedDBError>
Resolves the primary key for the first matching row inside the transaction.
Sourcepub async fn get_all(
&mut self,
values: &[Value],
range: Option<KeyRange>,
) -> Result<Vec<Record>, IndexedDBError>
pub async fn get_all( &mut self, values: &[Value], range: Option<KeyRange>, ) -> Result<Vec<Record>, IndexedDBError>
Loads every row that matches values and range inside the transaction.
Sourcepub async fn get_all_keys(
&mut self,
values: &[Value],
range: Option<KeyRange>,
) -> Result<Vec<String>, IndexedDBError>
pub async fn get_all_keys( &mut self, values: &[Value], range: Option<KeyRange>, ) -> Result<Vec<String>, IndexedDBError>
Loads every primary key that matches values and range inside the transaction.