#[repr(i32)]pub enum ProviderKind {
Unspecified = 0,
Integration = 1,
Auth = 2,
Indexeddb = 3,
Secrets = 4,
Telemetry = 5,
Cache = 6,
S3 = 7,
}Variants
Implementations
Sourceimpl ProviderKind
impl ProviderKind
Sourceimpl ProviderKind
impl ProviderKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.