pub struct AgentInteraction {
pub id: String,
pub type: i32,
pub state: i32,
pub title: String,
pub prompt: String,
pub request: Option<Struct>,
pub resolution: Option<Struct>,
pub created_at: Option<Timestamp>,
pub resolved_at: Option<Timestamp>,
pub turn_id: String,
pub session_id: String,
}Fields
id: Stringtype: i32state: i32title: Stringprompt: Stringrequest: Option<Struct>resolution: Option<Struct>created_at: Option<Timestamp>resolved_at: Option<Timestamp>turn_id: Stringsession_id: StringImplementations
Sourceimpl AgentInteraction
impl AgentInteraction
Sourcepub fn type(&self) -> AgentInteractionType
pub fn type(&self) -> AgentInteractionType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: AgentInteractionType)
pub fn set_type(&mut self, value: AgentInteractionType)
Sets type to the provided enum value.
Sourcepub fn state(&self) -> AgentInteractionState
pub fn state(&self) -> AgentInteractionState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: AgentInteractionState)
pub fn set_state(&mut self, value: AgentInteractionState)
Sets state to the provided enum value.