pub struct AgentManagerListSessionsRequest {
pub provider_name: String,
pub invocation_token: String,
pub state: i32,
pub limit: i32,
pub summary_only: bool,
}Fields
provider_name: Stringinvocation_token: Stringstate: i32limit: i32Manager response cap after provider responses are normalized and globally sorted by session recency.
summary_only: boolImplementations
Sourceimpl AgentManagerListSessionsRequest
impl AgentManagerListSessionsRequest
Sourcepub fn state(&self) -> AgentSessionState
pub fn state(&self) -> AgentSessionState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: AgentSessionState)
pub fn set_state(&mut self, value: AgentSessionState)
Sets state to the provided enum value.