pub struct AgentManagerListTurnsRequest {
pub session_id: String,
pub invocation_token: String,
pub status: i32,
pub limit: i32,
pub summary_only: bool,
}Fields
session_id: Stringinvocation_token: Stringstatus: i32limit: i32summary_only: boolImplementations
Sourceimpl AgentManagerListTurnsRequest
impl AgentManagerListTurnsRequest
Sourcepub fn status(&self) -> AgentExecutionStatus
pub fn status(&self) -> AgentExecutionStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: AgentExecutionStatus)
pub fn set_status(&mut self, value: AgentExecutionStatus)
Sets status to the provided enum value.