pub struct AgentManagerUpdateSessionRequest {
pub session_id: String,
pub client_ref: String,
pub state: i32,
pub metadata: Option<Struct>,
pub invocation_token: String,
}Fields
session_id: Stringclient_ref: Stringstate: i32metadata: Option<Struct>invocation_token: StringImplementations
Sourceimpl AgentManagerUpdateSessionRequest
impl AgentManagerUpdateSessionRequest
Sourcepub fn state(&self) -> AgentSessionState
pub fn state(&self) -> AgentSessionState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: AgentSessionState)
pub fn set_state(&mut self, value: AgentSessionState)
Sets state to the provided enum value.