pub struct AgentMessagePart {
pub type: i32,
pub text: String,
pub json: Option<Struct>,
pub tool_call: Option<AgentMessagePartToolCall>,
pub tool_result: Option<AgentMessagePartToolResult>,
pub image_ref: Option<AgentMessagePartImageRef>,
}Fields
type: i32text: Stringjson: Option<Struct>tool_call: Option<AgentMessagePartToolCall>tool_result: Option<AgentMessagePartToolResult>image_ref: Option<AgentMessagePartImageRef>Implementations
Sourceimpl AgentMessagePart
impl AgentMessagePart
Sourcepub fn type(&self) -> AgentMessagePartType
pub fn type(&self) -> AgentMessagePartType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: AgentMessagePartType)
pub fn set_type(&mut self, value: AgentMessagePartType)
Sets type to the provided enum value.