pub struct AgentSession {
pub id: String,
pub provider_name: String,
pub model: String,
pub client_ref: String,
pub state: i32,
pub metadata: Option<Struct>,
pub created_by: Option<AgentActor>,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
pub last_turn_at: Option<Timestamp>,
}Fields
id: Stringprovider_name: Stringmodel: Stringclient_ref: Stringstate: i32metadata: Option<Struct>created_by: Option<AgentActor>created_at: Option<Timestamp>updated_at: Option<Timestamp>last_turn_at: Option<Timestamp>Implementations
Sourceimpl AgentSession
impl AgentSession
Sourcepub fn state(&self) -> AgentSessionState
pub fn state(&self) -> AgentSessionState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: AgentSessionState)
pub fn set_state(&mut self, value: AgentSessionState)
Sets state to the provided enum value.