pub struct AgentTurn {Show 14 fields
pub id: String,
pub session_id: String,
pub provider_name: String,
pub model: String,
pub status: i32,
pub messages: Vec<AgentMessage>,
pub output_text: String,
pub structured_output: Option<Struct>,
pub status_message: String,
pub created_by: Option<AgentActor>,
pub created_at: Option<Timestamp>,
pub started_at: Option<Timestamp>,
pub completed_at: Option<Timestamp>,
pub execution_ref: String,
}Fields
id: Stringsession_id: Stringprovider_name: Stringmodel: Stringstatus: i32messages: Vec<AgentMessage>output_text: Stringstructured_output: Option<Struct>status_message: Stringcreated_by: Option<AgentActor>created_at: Option<Timestamp>started_at: Option<Timestamp>completed_at: Option<Timestamp>execution_ref: StringImplementations
Sourceimpl AgentTurn
impl AgentTurn
Sourcepub fn status(&self) -> AgentExecutionStatus
pub fn status(&self) -> AgentExecutionStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: AgentExecutionStatus)
pub fn set_status(&mut self, value: AgentExecutionStatus)
Sets status to the provided enum value.