pub struct BeginTransactionRequest {
pub stores: Vec<String>,
pub mode: i32,
pub durability_hint: i32,
}Expand description
BeginTransactionRequest starts an IndexedDB transaction stream.
Fields
stores: Vec<String>mode: i32durability_hint: i32Implementations
Sourceimpl BeginTransactionRequest
impl BeginTransactionRequest
Sourcepub fn mode(&self) -> TransactionMode
pub fn mode(&self) -> TransactionMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: TransactionMode)
pub fn set_mode(&mut self, value: TransactionMode)
Sets mode to the provided enum value.
Sourcepub fn durability_hint(&self) -> TransactionDurabilityHint
pub fn durability_hint(&self) -> TransactionDurabilityHint
Returns the enum value of durability_hint, or the default if the field is set to an invalid enum value.
Sourcepub fn set_durability_hint(&mut self, value: TransactionDurabilityHint)
pub fn set_durability_hint(&mut self, value: TransactionDurabilityHint)
Sets durability_hint to the provided enum value.