pub struct BoundWorkflowAgentTarget {
pub provider_name: String,
pub model: String,
pub prompt: String,
pub messages: Vec<AgentMessage>,
pub tool_refs: Vec<AgentToolRef>,
pub response_schema: Option<Struct>,
pub metadata: Option<Struct>,
pub timeout_seconds: i32,
pub output_delivery: Option<WorkflowOutputDelivery>,
pub model_options: Option<Struct>,
}Fields
provider_name: Stringmodel: Stringprompt: Stringmessages: Vec<AgentMessage>tool_refs: Vec<AgentToolRef>response_schema: Option<Struct>metadata: Option<Struct>timeout_seconds: i32output_delivery: Option<WorkflowOutputDelivery>model_options: Option<Struct>Trait Implementations
Sourceimpl Clone for BoundWorkflowAgentTarget
impl Clone for BoundWorkflowAgentTarget
Sourcefn clone(&self) -> BoundWorkflowAgentTarget
fn clone(&self) -> BoundWorkflowAgentTarget
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BoundWorkflowAgentTarget
impl Debug for BoundWorkflowAgentTarget
Sourceimpl Default for BoundWorkflowAgentTarget
impl Default for BoundWorkflowAgentTarget
Sourceimpl Message for BoundWorkflowAgentTarget
impl Message for BoundWorkflowAgentTarget
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BoundWorkflowAgentTarget
impl PartialEq for BoundWorkflowAgentTarget
impl StructuralPartialEq for BoundWorkflowAgentTarget