pub struct BoundWorkflowRun {
pub id: String,
pub status: i32,
pub target: Option<BoundWorkflowTarget>,
pub trigger: Option<WorkflowRunTrigger>,
pub created_at: Option<Timestamp>,
pub started_at: Option<Timestamp>,
pub completed_at: Option<Timestamp>,
pub status_message: String,
pub result_body: String,
pub created_by: Option<WorkflowActor>,
pub execution_ref: String,
pub workflow_key: String,
}Fields
id: Stringstatus: i32target: Option<BoundWorkflowTarget>trigger: Option<WorkflowRunTrigger>created_at: Option<Timestamp>started_at: Option<Timestamp>completed_at: Option<Timestamp>status_message: Stringresult_body: Stringcreated_by: Option<WorkflowActor>execution_ref: Stringworkflow_key: StringImplementations
Sourceimpl BoundWorkflowRun
impl BoundWorkflowRun
Sourcepub fn status(&self) -> WorkflowRunStatus
pub fn status(&self) -> WorkflowRunStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: WorkflowRunStatus)
pub fn set_status(&mut self, value: WorkflowRunStatus)
Sets status to the provided enum value.