pub struct BoundWorkflowSchedule {
pub id: String,
pub cron: String,
pub timezone: String,
pub target: Option<BoundWorkflowTarget>,
pub paused: bool,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
pub next_run_at: Option<Timestamp>,
pub created_by: Option<WorkflowActor>,
pub execution_ref: String,
}Fields
id: Stringcron: Stringtimezone: Stringtarget: Option<BoundWorkflowTarget>paused: boolcreated_at: Option<Timestamp>updated_at: Option<Timestamp>next_run_at: Option<Timestamp>created_by: Option<WorkflowActor>execution_ref: StringTrait Implementations
Sourceimpl Clone for BoundWorkflowSchedule
impl Clone for BoundWorkflowSchedule
Sourcefn clone(&self) -> BoundWorkflowSchedule
fn clone(&self) -> BoundWorkflowSchedule
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BoundWorkflowSchedule
impl Debug for BoundWorkflowSchedule
Sourceimpl Default for BoundWorkflowSchedule
impl Default for BoundWorkflowSchedule
Sourceimpl Message for BoundWorkflowSchedule
impl Message for BoundWorkflowSchedule
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BoundWorkflowSchedule
impl PartialEq for BoundWorkflowSchedule
impl StructuralPartialEq for BoundWorkflowSchedule