pub struct CreateObjectAccessUrlResponse {
pub url: String,
pub method: i32,
pub expires_at: Option<Timestamp>,
pub headers: BTreeMap<String, String>,
}Expand description
CreateObjectAccessURLResponse returns a hosted object-access URL plus any headers the caller must include when using it.
Fields
url: Stringmethod: i32expires_at: Option<Timestamp>headers: BTreeMap<String, String>Implementations
Sourceimpl CreateObjectAccessUrlResponse
impl CreateObjectAccessUrlResponse
Sourcepub fn method(&self) -> PresignMethod
pub fn method(&self) -> PresignMethod
Returns the enum value of method, or the default if the field is set to an invalid enum value.
Sourcepub fn set_method(&mut self, value: PresignMethod)
pub fn set_method(&mut self, value: PresignMethod)
Sets method to the provided enum value.