pub struct HttpSubjectRequest {
pub binding: String,
pub method: String,
pub path: String,
pub content_type: String,
pub headers: BTreeMap<String, StringList>,
pub query: BTreeMap<String, StringList>,
pub params: Option<Struct>,
pub raw_body: Vec<u8>,
pub security_scheme: String,
pub verified_subject: String,
pub verified_claims: BTreeMap<String, String>,
}Expand description
HTTPSubjectRequest carries one verified hosted HTTP request into an optional plugin-local subject resolution hook.
Fields
binding: Stringmethod: Stringpath: Stringcontent_type: Stringheaders: BTreeMap<String, StringList>query: BTreeMap<String, StringList>params: Option<Struct>raw_body: Vec<u8>security_scheme: Stringverified_subject: Stringverified_claims: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for HttpSubjectRequest
impl Clone for HttpSubjectRequest
Sourcefn clone(&self) -> HttpSubjectRequest
fn clone(&self) -> HttpSubjectRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HttpSubjectRequest
impl Debug for HttpSubjectRequest
Sourceimpl Default for HttpSubjectRequest
impl Default for HttpSubjectRequest
Sourceimpl Message for HttpSubjectRequest
impl Message for HttpSubjectRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for HttpSubjectRequest
impl PartialEq for HttpSubjectRequest
impl StructuralPartialEq for HttpSubjectRequest