pub struct OpenCursorRequest {
pub store: String,
pub range: Option<KeyRange>,
pub direction: i32,
pub keys_only: bool,
pub index: String,
pub values: Vec<TypedValue>,
}Fields
store: Stringrange: Option<KeyRange>direction: i32keys_only: boolindex: Stringvalues: Vec<TypedValue>Implementations
Sourceimpl OpenCursorRequest
impl OpenCursorRequest
Sourcepub fn direction(&self) -> CursorDirection
pub fn direction(&self) -> CursorDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: CursorDirection)
pub fn set_direction(&mut self, value: CursorDirection)
Sets direction to the provided enum value.