pub struct PluginRuntimeLogEntry {
pub stream: i32,
pub message: String,
pub observed_at: Option<Timestamp>,
pub source_seq: i64,
}Fields
stream: i32message: Stringobserved_at: Option<Timestamp>source_seq: i64Implementations
Sourceimpl PluginRuntimeLogEntry
impl PluginRuntimeLogEntry
Sourcepub fn stream(&self) -> PluginRuntimeLogStream
pub fn stream(&self) -> PluginRuntimeLogStream
Returns the enum value of stream, or the default if the field is set to an invalid enum value.
Sourcepub fn set_stream(&mut self, value: PluginRuntimeLogStream)
pub fn set_stream(&mut self, value: PluginRuntimeLogStream)
Sets stream to the provided enum value.