pub struct PostConnectCredential {Show 14 fields
pub id: String,
pub subject_id: String,
pub integration: String,
pub instance: String,
pub access_token: String,
pub refresh_token: String,
pub scopes: String,
pub expires_at: Option<Timestamp>,
pub last_refreshed_at: Option<Timestamp>,
pub refresh_error_count: i32,
pub metadata_json: String,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
pub connection: String,
}Expand description
PostConnectCredential is the host-managed credential payload passed into post-connect hooks. Field numbers intentionally match the legacy post-connect credential payload so older compiled providers can still decode the request during rolling upgrades.
Fields
id: Stringsubject_id: Stringintegration: Stringinstance: Stringaccess_token: Stringrefresh_token: Stringscopes: Stringexpires_at: Option<Timestamp>last_refreshed_at: Option<Timestamp>refresh_error_count: i32metadata_json: Stringcreated_at: Option<Timestamp>updated_at: Option<Timestamp>connection: StringTrait Implementations
Sourceimpl Clone for PostConnectCredential
impl Clone for PostConnectCredential
Sourcefn clone(&self) -> PostConnectCredential
fn clone(&self) -> PostConnectCredential
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PostConnectCredential
impl Debug for PostConnectCredential
Sourceimpl Default for PostConnectCredential
impl Default for PostConnectCredential
Sourceimpl Hash for PostConnectCredential
impl Hash for PostConnectCredential
Sourceimpl Message for PostConnectCredential
impl Message for PostConnectCredential
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PostConnectCredential
impl PartialEq for PostConnectCredential
impl Eq for PostConnectCredential
impl StructuralPartialEq for PostConnectCredential