pub struct PresignObjectRequest {
pub ref: Option<S3ObjectRef>,
pub method: i32,
pub expires_seconds: i64,
pub content_type: String,
pub content_disposition: String,
pub headers: BTreeMap<String, String>,
}Fields
ref: Option<S3ObjectRef>method: i32expires_seconds: i64content_type: Stringcontent_disposition: Stringheaders: BTreeMap<String, String>Implementations
Sourceimpl PresignObjectRequest
impl PresignObjectRequest
Sourcepub fn method(&self) -> PresignMethod
pub fn method(&self) -> PresignMethod
Returns the enum value of method, or the default if the field is set to an invalid enum value.
Sourcepub fn set_method(&mut self, value: PresignMethod)
pub fn set_method(&mut self, value: PresignMethod)
Sets method to the provided enum value.