pub struct PresignObjectResponse {
pub url: String,
pub method: i32,
pub expires_at: Option<Timestamp>,
pub headers: BTreeMap<String, String>,
}Fields
url: Stringmethod: i32expires_at: Option<Timestamp>headers: BTreeMap<String, String>Implementations
Sourceimpl PresignObjectResponse
impl PresignObjectResponse
Sourcepub fn method(&self) -> PresignMethod
pub fn method(&self) -> PresignMethod
Returns the enum value of method, or the default if the field is set to an invalid enum value.
Sourcepub fn set_method(&mut self, value: PresignMethod)
pub fn set_method(&mut self, value: PresignMethod)
Sets method to the provided enum value.