pub struct ProviderIdentity {
pub kind: i32,
pub name: String,
pub display_name: String,
pub description: String,
pub version: String,
pub warnings: Vec<String>,
pub min_protocol_version: i32,
pub max_protocol_version: i32,
}Fields
kind: i32name: Stringdisplay_name: Stringdescription: Stringversion: Stringwarnings: Vec<String>min_protocol_version: i32max_protocol_version: i32Implementations
Sourceimpl ProviderIdentity
impl ProviderIdentity
Sourcepub fn kind(&self) -> ProviderKind
pub fn kind(&self) -> ProviderKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: ProviderKind)
pub fn set_kind(&mut self, value: ProviderKind)
Sets kind to the provided enum value.