pub struct ReadObjectRequest {
pub ref: Option<S3ObjectRef>,
pub range: Option<ByteRange>,
pub if_match: String,
pub if_none_match: String,
pub if_modified_since: Option<Timestamp>,
pub if_unmodified_since: Option<Timestamp>,
}Fields
ref: Option<S3ObjectRef>range: Option<ByteRange>if_match: Stringif_none_match: Stringif_modified_since: Option<Timestamp>if_unmodified_since: Option<Timestamp>Trait Implementations
Sourceimpl Clone for ReadObjectRequest
impl Clone for ReadObjectRequest
Sourcefn clone(&self) -> ReadObjectRequest
fn clone(&self) -> ReadObjectRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReadObjectRequest
impl Debug for ReadObjectRequest
Sourceimpl Default for ReadObjectRequest
impl Default for ReadObjectRequest
Sourceimpl Hash for ReadObjectRequest
impl Hash for ReadObjectRequest
Sourceimpl Message for ReadObjectRequest
impl Message for ReadObjectRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ReadObjectRequest
impl PartialEq for ReadObjectRequest
impl Eq for ReadObjectRequest
impl StructuralPartialEq for ReadObjectRequest