pub struct StartHostedPluginRequest {
pub session_id: String,
pub plugin_name: String,
pub command: String,
pub args: Vec<String>,
pub env: BTreeMap<String, String>,
pub allowed_hosts: Vec<String>,
pub default_action: String,
pub host_binary: String,
}Expand description
StartHostedPluginRequest describes the plugin process to launch inside a runtime session. The runtime backend owns allocation and injection of the plugin’s listener endpoint and returns a host-reachable dial target in the HostedPlugin response.
Fields
session_id: Stringplugin_name: Stringcommand: Stringargs: Vec<String>env: BTreeMap<String, String>allowed_hosts: Vec<String>default_action: Stringhost_binary: StringTrait Implementations
Sourceimpl Clone for StartHostedPluginRequest
impl Clone for StartHostedPluginRequest
Sourcefn clone(&self) -> StartHostedPluginRequest
fn clone(&self) -> StartHostedPluginRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StartHostedPluginRequest
impl Debug for StartHostedPluginRequest
Sourceimpl Default for StartHostedPluginRequest
impl Default for StartHostedPluginRequest
Sourceimpl Message for StartHostedPluginRequest
impl Message for StartHostedPluginRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for StartHostedPluginRequest
impl PartialEq for StartHostedPluginRequest
impl StructuralPartialEq for StartHostedPluginRequest