pub struct WorkflowExecutionReference {
pub id: String,
pub provider_name: String,
pub target: Option<BoundWorkflowTarget>,
pub subject_id: String,
pub credential_subject_id: String,
pub permissions: Vec<WorkflowAccessPermission>,
pub created_at: Option<Timestamp>,
pub revoked_at: Option<Timestamp>,
pub subject_kind: String,
pub display_name: String,
pub auth_source: String,
pub caller_plugin_name: String,
}Fields
id: Stringprovider_name: Stringtarget: Option<BoundWorkflowTarget>subject_id: Stringcredential_subject_id: Stringpermissions: Vec<WorkflowAccessPermission>created_at: Option<Timestamp>revoked_at: Option<Timestamp>subject_kind: Stringdisplay_name: Stringauth_source: Stringcaller_plugin_name: StringTrait Implementations
Sourceimpl Clone for WorkflowExecutionReference
impl Clone for WorkflowExecutionReference
Sourcefn clone(&self) -> WorkflowExecutionReference
fn clone(&self) -> WorkflowExecutionReference
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkflowExecutionReference
impl Debug for WorkflowExecutionReference
Sourceimpl Default for WorkflowExecutionReference
impl Default for WorkflowExecutionReference
Sourceimpl Message for WorkflowExecutionReference
impl Message for WorkflowExecutionReference
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for WorkflowExecutionReference