pub fn run_agent_provider<P: AgentProvider>(provider: Arc<P>) -> Result<()>Expand description
Runs an agent provider on the Unix socket exposed by gestaltd.
pub fn run_agent_provider<P: AgentProvider>(provider: Arc<P>) -> Result<()>Runs an agent provider on the Unix socket exposed by gestaltd.