pub fn run_cache_provider<P: CacheProvider>(provider: Arc<P>) -> Result<()>Expand description
Runs a cache provider on the Unix socket exposed by gestaltd.
pub fn run_cache_provider<P: CacheProvider>(provider: Arc<P>) -> Result<()>Runs a cache provider on the Unix socket exposed by gestaltd.