pub fn run_plugin_runtime_provider<P: PluginRuntimeProvider>(
provider: Arc<P>,
) -> Result<()>Expand description
Runs a plugin-runtime provider on the Unix socket exposed by gestaltd.
pub fn run_plugin_runtime_provider<P: PluginRuntimeProvider>(
provider: Arc<P>,
) -> Result<()>Runs a plugin-runtime provider on the Unix socket exposed by gestaltd.