pub fn run_runtime_provider<P: RuntimeProvider>(provider: Arc<P>) -> Result<()>Expand description
Runs a runtime provider on the Unix socket exposed by gestaltd.
pub fn run_runtime_provider<P: RuntimeProvider>(provider: Arc<P>) -> Result<()>Runs a runtime provider on the Unix socket exposed by gestaltd.