pub async fn serve_agent_provider<P>(provider: Arc<P>) -> Result<()>where
P: AgentProvider,Expand description
Serves an agent provider over the configured Unix socket.
pub async fn serve_agent_provider<P>(provider: Arc<P>) -> Result<()>where
P: AgentProvider,Serves an agent provider over the configured Unix socket.