pub async fn serve_authentication_provider<P>(provider: Arc<P>) -> Result<()>where
P: AuthenticationProvider,Expand description
Serves an authentication provider over the configured Unix socket.
pub async fn serve_authentication_provider<P>(provider: Arc<P>) -> Result<()>where
P: AuthenticationProvider,Serves an authentication provider over the configured Unix socket.