pub async fn serve_runtime_provider<P>(provider: Arc<P>) -> Result<()>where
P: RuntimeProvider,Expand description
Serves a runtime provider over the configured Unix socket.
pub async fn serve_runtime_provider<P>(provider: Arc<P>) -> Result<()>where
P: RuntimeProvider,Serves a runtime provider over the configured Unix socket.