pub struct PrepareRuntimeWorkspaceRequest {
pub session_id: String,
pub agent_session_id: String,
pub workspace: Option<AgentWorkspace>,
}Expand description
Native message type for gestalt.provider.v1.PrepareRuntimeWorkspaceRequest.
Fields
session_id: StringThe session_id field.
agent_session_id: StringOpaque, path-safe workspace key minted by the host. Despite the name it is not required to match any agent session id; it only identifies the prepared workspace directory for later removal.
The agent_session_id field.
workspace: Option<AgentWorkspace>The workspace field; None when unset.