pub struct ObjectReader { /* private fields */ }Expand description
Streaming reader returned by S3::read_object and Object::stream.
Implementations
Sourceimpl ObjectReader
impl ObjectReader
Sourcepub fn meta(&self) -> &ObjectMeta
pub fn meta(&self) -> &ObjectMeta
Returns the metadata frame emitted at the start of the stream.
Sourcepub async fn next_chunk(&mut self) -> Result<Option<Vec<u8>>, S3Error>
pub async fn next_chunk(&mut self) -> Result<Option<Vec<u8>>, S3Error>
Returns the next non-empty body chunk.
Sourcepub async fn bytes(self) -> Result<Vec<u8>, S3Error>
pub async fn bytes(self) -> Result<Vec<u8>, S3Error>
Reads the remainder of the stream into memory.
Sourcepub async fn text(self) -> Result<String, S3Error>
pub async fn text(self) -> Result<String, S3Error>
Reads the remainder of the stream as UTF-8 text.
Sourcepub async fn json<T>(self) -> Result<T, S3Error>where
T: DeserializeOwned,
pub async fn json<T>(self) -> Result<T, S3Error>where
T: DeserializeOwned,
Reads and decodes the remainder of the stream as JSON.