pub struct AgentHost { /* private fields */ }Expand description
Client for the agent host service available inside agent providers.
Implementations
Sourceimpl AgentHost
impl AgentHost
Sourcepub async fn connect() -> Result<Self, AgentHostError>
pub async fn connect() -> Result<Self, AgentHostError>
Connects to the agent host service described by the environment.
Sourcepub async fn execute_tool(
&mut self,
request: ExecuteAgentToolRequest,
) -> Result<ExecuteAgentToolResponse, AgentHostError>
pub async fn execute_tool( &mut self, request: ExecuteAgentToolRequest, ) -> Result<ExecuteAgentToolResponse, AgentHostError>
Executes a host tool using an agent protocol request message.
Sourcepub async fn list_tools(
&mut self,
request: ListAgentToolsRequest,
) -> Result<ListAgentToolsResponse, AgentHostError>
pub async fn list_tools( &mut self, request: ListAgentToolsRequest, ) -> Result<ListAgentToolsResponse, AgentHostError>
Lists host tools visible to the current agent request.
Sourcepub async fn resolve_connection(
&mut self,
request: ResolveAgentConnectionRequest,
) -> Result<ResolvedAgentConnection, AgentHostError>
pub async fn resolve_connection( &mut self, request: ResolveAgentConnectionRequest, ) -> Result<ResolvedAgentConnection, AgentHostError>
Resolves a configured agent connection for the current turn.