pub struct Credential {
pub mode: String,
pub subject_id: String,
pub connection: String,
pub instance: String,
}Expand description
Describes the resolved credential used to authorize an operation.
Fields
mode: StringCredential mode used by the host.
subject_id: StringSubject id associated with the credential.
connection: StringConnection id or name associated with the credential.
instance: StringProvider instance id or name associated with the credential.