pub struct Index { /* private fields */ }Expand description
Lookup and cursor access through one secondary index.
Implementations
Sourceimpl Index
impl Index
Sourcepub async fn get(
&mut self,
query: impl Into<Query>,
) -> Result<Record, IndexedDBError>
pub async fn get( &mut self, query: impl Into<Query>, ) -> Result<Record, IndexedDBError>
Loads the first row that matches query.
Sourcepub async fn get_key(
&mut self,
query: impl Into<Query>,
) -> Result<String, IndexedDBError>
pub async fn get_key( &mut self, query: impl Into<Query>, ) -> Result<String, IndexedDBError>
Resolves the primary key for the first row that matches query.
Sourcepub async fn get_all(
&mut self,
query: impl Into<Query>,
count: Option<u32>,
) -> Result<Vec<Record>, IndexedDBError>
pub async fn get_all( &mut self, query: impl Into<Query>, count: Option<u32>, ) -> Result<Vec<Record>, IndexedDBError>
Loads every row that matches query.
Sourcepub async fn get_all_keys(
&mut self,
query: impl Into<Query>,
count: Option<u32>,
) -> Result<Vec<String>, IndexedDBError>
pub async fn get_all_keys( &mut self, query: impl Into<Query>, count: Option<u32>, ) -> Result<Vec<String>, IndexedDBError>
Loads every primary key that matches query.
Sourcepub async fn count(
&mut self,
query: impl Into<Query>,
) -> Result<i64, IndexedDBError>
pub async fn count( &mut self, query: impl Into<Query>, ) -> Result<i64, IndexedDBError>
Counts rows that match query.
Sourcepub async fn delete(
&mut self,
query: impl Into<Query>,
) -> Result<i64, IndexedDBError>
pub async fn delete( &mut self, query: impl Into<Query>, ) -> Result<i64, IndexedDBError>
Deletes rows that match query and returns the delete count.
Sourcepub async fn open_cursor(
&mut self,
query: impl Into<Query>,
direction: CursorDirection,
) -> Result<Cursor, IndexedDBError>
pub async fn open_cursor( &mut self, query: impl Into<Query>, direction: CursorDirection, ) -> Result<Cursor, IndexedDBError>
Opens a full-value cursor over the secondary index.
Sourcepub async fn open_key_cursor(
&mut self,
query: impl Into<Query>,
direction: CursorDirection,
) -> Result<Cursor, IndexedDBError>
pub async fn open_key_cursor( &mut self, query: impl Into<Query>, direction: CursorDirection, ) -> Result<Cursor, IndexedDBError>
Opens a key-only cursor over the secondary index.