pub struct InvocationGrant {
pub plugin: String,
pub operations: Vec<String>,
pub surfaces: Vec<String>,
pub all_operations: bool,
}Expand description
Grant included when exchanging an invocation token for a child token.
Fields
plugin: StringPlugin name that the child token may invoke.
operations: Vec<String>Specific operation ids allowed by the child token.
surfaces: Vec<String>Surface names allowed by the child token.
all_operations: boolWhether the child token may invoke every operation on the plugin.