pub struct KeyRange {
pub lower: Option<Key>,
pub upper: Option<Key>,
pub lower_open: bool,
pub upper_open: bool,
}Expand description
Constrains a query or cursor by lower and upper bounds.
Fields
lower: Option<Key>Lower bound, inclusive unless lower_open is true.
upper: Option<Key>Upper bound, inclusive unless upper_open is true.
lower_open: boolWhether the lower bound is exclusive.
upper_open: boolWhether the upper bound is exclusive.
Implementations
Sourceimpl KeyRange
impl KeyRange
Sourcepub fn bound(
lower: impl Into<Key>,
upper: impl Into<Key>,
lower_open: bool,
upper_open: bool,
) -> Self
pub fn bound( lower: impl Into<Key>, upper: impl Into<Key>, lower_open: bool, upper_open: bool, ) -> Self
Returns a range between optional lower and upper bounds.
Sourcepub fn lower_bound(key: impl Into<Key>, open: bool) -> Self
pub fn lower_bound(key: impl Into<Key>, open: bool) -> Self
Returns a range with only a lower bound.
Sourcepub fn upper_bound(key: impl Into<Key>, open: bool) -> Self
pub fn upper_bound(key: impl Into<Key>, open: bool) -> Self
Returns a range with only an upper bound.