pub struct ObjectStore { /* private fields */ }Expand description
CRUD, range-query, and cursor access for one object store.
Implementations
Sourceimpl ObjectStore
impl ObjectStore
Sourcepub async fn get(&mut self, id: &str) -> Result<Record, IndexedDBError>
pub async fn get(&mut self, id: &str) -> Result<Record, IndexedDBError>
Loads one record by primary key.
Sourcepub async fn get_key(&mut self, id: &str) -> Result<String, IndexedDBError>
pub async fn get_key(&mut self, id: &str) -> Result<String, IndexedDBError>
Resolves the primary key for id.
Sourcepub async fn add(&mut self, record: Record) -> Result<(), IndexedDBError>
pub async fn add(&mut self, record: Record) -> Result<(), IndexedDBError>
Inserts a new row and fails if the key already exists.
Sourcepub async fn put(&mut self, record: Record) -> Result<(), IndexedDBError>
pub async fn put(&mut self, record: Record) -> Result<(), IndexedDBError>
Upserts a row by primary key.
Sourcepub async fn delete(&mut self, id: &str) -> Result<(), IndexedDBError>
pub async fn delete(&mut self, id: &str) -> Result<(), IndexedDBError>
Deletes one row by primary key.
Sourcepub async fn clear(&mut self) -> Result<(), IndexedDBError>
pub async fn clear(&mut self) -> Result<(), IndexedDBError>
Deletes every row in the object store.
Sourcepub async fn get_all(
&mut self,
range: Option<KeyRange>,
) -> Result<Vec<Record>, IndexedDBError>
pub async fn get_all( &mut self, range: Option<KeyRange>, ) -> Result<Vec<Record>, IndexedDBError>
Loads every row that matches range.
Sourcepub async fn get_all_keys(
&mut self,
range: Option<KeyRange>,
) -> Result<Vec<String>, IndexedDBError>
pub async fn get_all_keys( &mut self, range: Option<KeyRange>, ) -> Result<Vec<String>, IndexedDBError>
Loads every primary key that matches range.
Sourcepub async fn count(
&mut self,
range: Option<KeyRange>,
) -> Result<i64, IndexedDBError>
pub async fn count( &mut self, range: Option<KeyRange>, ) -> Result<i64, IndexedDBError>
Counts rows that match range.
Sourcepub async fn delete_range(
&mut self,
range: KeyRange,
) -> Result<i64, IndexedDBError>
pub async fn delete_range( &mut self, range: KeyRange, ) -> Result<i64, IndexedDBError>
Deletes rows that match range and returns the delete count.
Sourcepub async fn open_cursor(
&mut self,
range: Option<KeyRange>,
direction: CursorDirection,
) -> Result<Cursor, IndexedDBError>
pub async fn open_cursor( &mut self, range: Option<KeyRange>, direction: CursorDirection, ) -> Result<Cursor, IndexedDBError>
Opens a full-value cursor over the object store.
Sourcepub async fn open_key_cursor(
&mut self,
range: Option<KeyRange>,
direction: CursorDirection,
) -> Result<Cursor, IndexedDBError>
pub async fn open_key_cursor( &mut self, range: Option<KeyRange>, direction: CursorDirection, ) -> Result<Cursor, IndexedDBError>
Opens a key-only cursor over the object store.