pub struct PluginInvoker { /* private fields */ }Expand description
Client for invoking sibling plugin operations through the host.
Implementations
Sourceimpl PluginInvoker
impl PluginInvoker
Sourcepub async fn connect(
invocation_token: impl AsRef<str>,
) -> Result<Self, PluginInvokerError>
pub async fn connect( invocation_token: impl AsRef<str>, ) -> Result<Self, PluginInvokerError>
Connects to the plugin invoker with an invocation token from the host.
Sourcepub async fn invoke<P>(
&mut self,
plugin: &str,
operation: &str,
params: P,
options: Option<InvokeOptions>,
) -> Result<OperationResult, PluginInvokerError>where
P: Serialize,
pub async fn invoke<P>(
&mut self,
plugin: &str,
operation: &str,
params: P,
options: Option<InvokeOptions>,
) -> Result<OperationResult, PluginInvokerError>where
P: Serialize,
Invokes one operation on another plugin.
Sourcepub async fn invoke_graphql<V>(
&mut self,
plugin: &str,
document: &str,
variables: Option<V>,
options: Option<InvokeOptions>,
) -> Result<OperationResult, PluginInvokerError>where
V: Serialize,
pub async fn invoke_graphql<V>(
&mut self,
plugin: &str,
document: &str,
variables: Option<V>,
options: Option<InvokeOptions>,
) -> Result<OperationResult, PluginInvokerError>where
V: Serialize,
Invokes another plugin’s GraphQL surface.
Sourcepub async fn exchange_invocation_token(
&mut self,
grants: &[InvocationGrant],
ttl: Option<Duration>,
) -> Result<String, PluginInvokerError>
pub async fn exchange_invocation_token( &mut self, grants: &[InvocationGrant], ttl: Option<Duration>, ) -> Result<String, PluginInvokerError>
Exchanges this invocation token for a narrower child token.