pub struct RuntimeLogHost { /* private fields */ }Expand description
Client for appending plugin-runtime logs to the host.
Implementations
Sourceimpl RuntimeLogHost
impl RuntimeLogHost
Sourcepub async fn connect() -> Result<Self, RuntimeLogHostError>
pub async fn connect() -> Result<Self, RuntimeLogHostError>
Connects to the runtime-log host service described by the environment.
Sourcepub async fn append_logs(
&mut self,
request: AppendPluginRuntimeLogsRequest,
) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
pub async fn append_logs( &mut self, request: AppendPluginRuntimeLogsRequest, ) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
Appends logs using a raw protocol request message.
Sourcepub async fn append(
&mut self,
session_id: impl Into<String>,
stream: RuntimeLogStream,
message: impl Into<String>,
) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
pub async fn append( &mut self, session_id: impl Into<String>, stream: RuntimeLogStream, message: impl Into<String>, ) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
Appends one log entry for an explicit session id.
Sourcepub async fn append_current(
&mut self,
stream: RuntimeLogStream,
message: impl Into<String>,
) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
pub async fn append_current( &mut self, stream: RuntimeLogStream, message: impl Into<String>, ) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
Appends one log entry for GESTALT_RUNTIME_SESSION_ID.
Sourcepub async fn append_entry(
&mut self,
session_id: impl Into<String>,
stream: RuntimeLogStream,
message: impl Into<String>,
observed_at: Option<Timestamp>,
source_seq: i64,
) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
pub async fn append_entry( &mut self, session_id: impl Into<String>, stream: RuntimeLogStream, message: impl Into<String>, observed_at: Option<Timestamp>, source_seq: i64, ) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
Appends one log entry with an explicit timestamp and source sequence.
Sourcepub async fn append_current_entry(
&mut self,
stream: RuntimeLogStream,
message: impl Into<String>,
observed_at: Option<Timestamp>,
source_seq: i64,
) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
pub async fn append_current_entry( &mut self, stream: RuntimeLogStream, message: impl Into<String>, observed_at: Option<Timestamp>, source_seq: i64, ) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
Appends one explicit log entry for GESTALT_RUNTIME_SESSION_ID.
Sourcepub async fn append_stdout(
&mut self,
session_id: impl Into<String>,
message: impl Into<String>,
) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
pub async fn append_stdout( &mut self, session_id: impl Into<String>, message: impl Into<String>, ) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
Appends one stdout log entry for an explicit session id.
Sourcepub async fn append_current_stdout(
&mut self,
message: impl Into<String>,
) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
pub async fn append_current_stdout( &mut self, message: impl Into<String>, ) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
Appends one stdout log entry for GESTALT_RUNTIME_SESSION_ID.
Sourcepub async fn append_stderr(
&mut self,
session_id: impl Into<String>,
message: impl Into<String>,
) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
pub async fn append_stderr( &mut self, session_id: impl Into<String>, message: impl Into<String>, ) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
Appends one stderr log entry for an explicit session id.
Sourcepub async fn append_current_stderr(
&mut self,
message: impl Into<String>,
) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
pub async fn append_current_stderr( &mut self, message: impl Into<String>, ) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
Appends one stderr log entry for GESTALT_RUNTIME_SESSION_ID.
Sourcepub async fn append_runtime(
&mut self,
session_id: impl Into<String>,
message: impl Into<String>,
) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
pub async fn append_runtime( &mut self, session_id: impl Into<String>, message: impl Into<String>, ) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
Appends one runtime log entry for an explicit session id.
Sourcepub async fn append_current_runtime(
&mut self,
message: impl Into<String>,
) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
pub async fn append_current_runtime( &mut self, message: impl Into<String>, ) -> Result<AppendPluginRuntimeLogsResponse, RuntimeLogHostError>
Appends one runtime log entry for GESTALT_RUNTIME_SESSION_ID.