pub struct Subject {
pub id: String,
pub credential_subject_id: String,
pub email: String,
pub display_name: String,
}Expand description
Identifies the caller that initiated an operation.
Fields
id: StringStable subject id.
credential_subject_id: StringSubject id used for credential lookup, when different from the actor.
email: StringEmail address resolved by the Gestalt host for user subjects.
display_name: StringHuman-readable display name resolved by the Gestalt host for user subjects.