pub struct TransactionIndex<'a> { /* private fields */ }Expand description
Secondary-index operations scoped to an explicit transaction.
Implementations
Sourceimpl TransactionIndex<'_>
impl TransactionIndex<'_>
Sourcepub async fn get(
&mut self,
query: impl Into<Query>,
) -> Result<Record, IndexedDBError>
pub async fn get( &mut self, query: impl Into<Query>, ) -> Result<Record, IndexedDBError>
Loads the first row that matches query inside the transaction.
Sourcepub async fn get_key(
&mut self,
query: impl Into<Query>,
) -> Result<String, IndexedDBError>
pub async fn get_key( &mut self, query: impl Into<Query>, ) -> Result<String, IndexedDBError>
Resolves the primary key for the first matching row inside the transaction.
Sourcepub async fn get_all(
&mut self,
query: impl Into<Query>,
count: Option<u32>,
) -> Result<Vec<Record>, IndexedDBError>
pub async fn get_all( &mut self, query: impl Into<Query>, count: Option<u32>, ) -> Result<Vec<Record>, IndexedDBError>
Loads every row that matches query inside the transaction.
Sourcepub async fn get_all_keys(
&mut self,
query: impl Into<Query>,
count: Option<u32>,
) -> Result<Vec<String>, IndexedDBError>
pub async fn get_all_keys( &mut self, query: impl Into<Query>, count: Option<u32>, ) -> Result<Vec<String>, IndexedDBError>
Loads every primary key that matches query inside the transaction.