pub struct TransactionObjectStore<'a> { /* private fields */ }Expand description
Object-store operations scoped to an explicit transaction.
Implementations
Sourceimpl TransactionObjectStore<'_>
impl TransactionObjectStore<'_>
Sourcepub async fn get(&mut self, id: &str) -> Result<Record, IndexedDBError>
pub async fn get(&mut self, id: &str) -> Result<Record, IndexedDBError>
Loads one record by primary key inside the transaction.
Sourcepub async fn get_key(&mut self, id: &str) -> Result<String, IndexedDBError>
pub async fn get_key(&mut self, id: &str) -> Result<String, IndexedDBError>
Resolves the primary key for id inside the transaction.
Sourcepub async fn add(&mut self, record: Record) -> Result<(), IndexedDBError>
pub async fn add(&mut self, record: Record) -> Result<(), IndexedDBError>
Inserts a new row inside the transaction.
Sourcepub async fn put(&mut self, record: Record) -> Result<(), IndexedDBError>
pub async fn put(&mut self, record: Record) -> Result<(), IndexedDBError>
Upserts a row inside the transaction.
Sourcepub async fn delete(&mut self, id: &str) -> Result<(), IndexedDBError>
pub async fn delete(&mut self, id: &str) -> Result<(), IndexedDBError>
Deletes one row inside the transaction.
Sourcepub async fn clear(&mut self) -> Result<(), IndexedDBError>
pub async fn clear(&mut self) -> Result<(), IndexedDBError>
Deletes every row in the object store inside the transaction.
Sourcepub async fn get_all(
&mut self,
range: Option<KeyRange>,
) -> Result<Vec<Record>, IndexedDBError>
pub async fn get_all( &mut self, range: Option<KeyRange>, ) -> Result<Vec<Record>, IndexedDBError>
Loads every row that matches range inside the transaction.
Sourcepub async fn get_all_keys(
&mut self,
range: Option<KeyRange>,
) -> Result<Vec<String>, IndexedDBError>
pub async fn get_all_keys( &mut self, range: Option<KeyRange>, ) -> Result<Vec<String>, IndexedDBError>
Loads every primary key that matches range inside the transaction.
Sourcepub async fn count(
&mut self,
range: Option<KeyRange>,
) -> Result<i64, IndexedDBError>
pub async fn count( &mut self, range: Option<KeyRange>, ) -> Result<i64, IndexedDBError>
Counts rows that match range inside the transaction.
Sourcepub async fn delete_range(
&mut self,
range: KeyRange,
) -> Result<i64, IndexedDBError>
pub async fn delete_range( &mut self, range: KeyRange, ) -> Result<i64, IndexedDBError>
Deletes rows that match range inside the transaction.
Sourcepub fn index<'a>(&'a mut self, name: &str) -> TransactionIndex<'a>
pub fn index<'a>(&'a mut self, name: &str) -> TransactionIndex<'a>
Returns a transaction-scoped secondary index.