pub struct GenAIOperation { /* private fields */ }Expand description
Records a GenAI span plus operation duration and token usage metrics.
Implementations
Sourceimpl GenAIOperation
impl GenAIOperation
Sourcepub fn mark_error(
&mut self,
error_type: impl Into<String>,
description: impl Into<String>,
)
pub fn mark_error( &mut self, error_type: impl Into<String>, description: impl Into<String>, )
Marks the operation span and duration metric as failed.
Sourcepub fn record_error<E>(&mut self, err: &E)where
E: Error + 'static,
pub fn record_error<E>(&mut self, err: &E)where
E: Error + 'static,
Records an error object and marks the operation as failed.
Sourcepub fn set_attribute(&mut self, attribute: KeyValue)
pub fn set_attribute(&mut self, attribute: KeyValue)
Sets a span attribute. gen_ai.response.model is also added to metric attributes.
Sourcepub fn set_response_metadata(
&mut self,
response_id: Option<&str>,
response_model: Option<&str>,
finish_reasons: &[&str],
)
pub fn set_response_metadata( &mut self, response_id: Option<&str>, response_model: Option<&str>, finish_reasons: &[&str], )
Attaches common GenAI response metadata to the span.
Sourcepub fn record_usage(&mut self, usage: TokenUsage)
pub fn record_usage(&mut self, usage: TokenUsage)
Records GenAI token usage on the span and token usage metric.