pub fn workflow_value_template(template: impl Into<String>) -> WorkflowValueExpand description
Builds a workflow value rendered from a text template.
pub fn workflow_value_template(template: impl Into<String>) -> WorkflowValueBuilds a workflow value rendered from a text template.