pub struct RequestContext {
pub subject: Option<SubjectContext>,
pub credential: Option<CredentialContext>,
pub access: Option<AccessContext>,
pub workflow: Option<Map<String, Value>>,
pub host: Option<HostContext>,
pub agent_subject: Option<SubjectContext>,
pub caller: Option<ProviderContext>,
pub invocation: Option<InvocationContext>,
pub tool_refs: Vec<AgentToolRef>,
pub tool_refs_set: bool,
pub request_meta: Option<RequestMetaContext>,
pub agent: Option<AgentInvocationContext>,
}Expand description
RequestContext bundles the caller, credential, access, and host metadata for one operation.
Native message type for gestalt.provider.v1.RequestContext.
Fields
subject: Option<SubjectContext>The subject field; None when unset.
credential: Option<CredentialContext>The credential field; None when unset.
access: Option<AccessContext>The access field; None when unset.
workflow: Option<Map<String, Value>>The workflow field; None when unset.
host: Option<HostContext>The host field; None when unset.
agent_subject: Option<SubjectContext>Original agent caller when an agent tool executes with delegated run-as identity.
The agent_subject field; None when unset.
caller: Option<ProviderContext>The caller field; None when unset.
invocation: Option<InvocationContext>The invocation field; None when unset.
tool_refs: Vec<AgentToolRef>Agent tool refs granted to the operation request, when the request is executing as an agent tool.
The tool_refs field.
tool_refs_set: boolPreserves the distinction between an omitted tool-ref context and an explicitly empty inherited tool-ref context.
The tool_refs_set field.
request_meta: Option<RequestMetaContext>The request_meta field; None when unset.
agent: Option<AgentInvocationContext>The agent field; None when unset.