Module runtime

Module runtime 

Runtime entrypoints for serving Gestalt provider surfaces over Unix sockets.

Functions

maybe_write_catalog
Writes the router’s derived catalog when GESTALT_PLUGIN_WRITE_CATALOG is set, returning whether anything was written.
run_agent_provider
Runs an agent provider on the Unix socket exposed by gestaltd.
run_authentication_provider
Runs an authentication provider on the Unix socket exposed by gestaltd.
run_cache_provider
Runs a cache provider on the Unix socket exposed by gestaltd.
run_plugin_runtime_provider
Runs a plugin-runtime provider on the Unix socket exposed by gestaltd.
run_provider
Runs an integration provider on the Unix socket exposed by gestaltd.
run_s3_provider
Runs an S3 provider on the Unix socket exposed by gestaltd.
run_secrets_provider
Runs a secrets provider on the Unix socket exposed by gestaltd.
run_workflow_provider
Runs a workflow provider on the Unix socket exposed by gestaltd.
serve_agent_provider
Serves an agent provider over the configured Unix socket.
serve_authentication_provider
Serves an authentication provider over the configured Unix socket.
serve_cache_provider
Serves a cache provider over the configured Unix socket.
serve_plugin_runtime_provider
Serves a plugin-runtime provider over the configured Unix socket.
serve_provider
Serves an integration provider over the configured Unix socket.
serve_s3_provider
Serves an S3 provider over the configured Unix socket.
serve_secrets_provider
Serves a secrets provider over the configured Unix socket.
serve_workflow_provider
Serves a workflow provider over the configured Unix socket.
write_catalog_path
Writes the router’s derived catalog to path.