Runtime entrypoints for serving Gestalt provider surfaces over Unix sockets.
Functions
- maybe_
write_ catalog - Writes the router’s derived catalog when
GESTALT_PLUGIN_WRITE_CATALOGis set, returning whether anything was written. - run_
agent_ provider - Runs an agent provider on the Unix socket exposed by
gestaltd. - run_
authentication_ provider - Runs an authentication provider on the Unix socket exposed by
gestaltd. - run_
cache_ provider - Runs a cache provider on the Unix socket exposed by
gestaltd. - run_
plugin_ runtime_ provider - Runs a plugin-runtime provider on the Unix socket exposed by
gestaltd. - run_
provider - Runs an integration provider on the Unix socket exposed by
gestaltd. - run_
s3_ provider - Runs an S3 provider on the Unix socket exposed by
gestaltd. - run_
secrets_ provider - Runs a secrets provider on the Unix socket exposed by
gestaltd. - run_
workflow_ provider - Runs a workflow provider on the Unix socket exposed by
gestaltd. - serve_
agent_ provider - Serves an agent provider over the configured Unix socket.
- serve_
authentication_ provider - Serves an authentication provider over the configured Unix socket.
- serve_
cache_ provider - Serves a cache provider over the configured Unix socket.
- serve_
plugin_ runtime_ provider - Serves a plugin-runtime provider over the configured Unix socket.
- serve_
provider - Serves an integration provider over the configured Unix socket.
- serve_
s3_ provider - Serves an S3 provider over the configured Unix socket.
- serve_
secrets_ provider - Serves a secrets provider over the configured Unix socket.
- serve_
workflow_ provider - Serves a workflow provider over the configured Unix socket.
- write_
catalog_ path - Writes the router’s derived catalog to path.