pub struct Index { /* private fields */ }Expand description
Lookup and cursor access through one secondary index.
Implementations
Sourceimpl Index
impl Index
Sourcepub async fn get(&mut self, values: &[Value]) -> Result<Record, IndexedDBError>
pub async fn get(&mut self, values: &[Value]) -> Result<Record, IndexedDBError>
Loads the first row that matches values.
Sourcepub async fn get_key(
&mut self,
values: &[Value],
) -> Result<String, IndexedDBError>
pub async fn get_key( &mut self, values: &[Value], ) -> Result<String, IndexedDBError>
Resolves the primary key for the first row that matches values.
Sourcepub async fn get_all(
&mut self,
values: &[Value],
range: Option<KeyRange>,
) -> Result<Vec<Record>, IndexedDBError>
pub async fn get_all( &mut self, values: &[Value], range: Option<KeyRange>, ) -> Result<Vec<Record>, IndexedDBError>
Loads every row that matches values and range.
Sourcepub async fn get_all_keys(
&mut self,
values: &[Value],
range: Option<KeyRange>,
) -> Result<Vec<String>, IndexedDBError>
pub async fn get_all_keys( &mut self, values: &[Value], range: Option<KeyRange>, ) -> Result<Vec<String>, IndexedDBError>
Loads every primary key that matches values and range.
Sourcepub async fn count(
&mut self,
values: &[Value],
range: Option<KeyRange>,
) -> Result<i64, IndexedDBError>
pub async fn count( &mut self, values: &[Value], range: Option<KeyRange>, ) -> Result<i64, IndexedDBError>
Counts rows that match values and range.
Sourcepub async fn delete(&mut self, values: &[Value]) -> Result<i64, IndexedDBError>
pub async fn delete(&mut self, values: &[Value]) -> Result<i64, IndexedDBError>
Deletes rows that match values and returns the delete count.
Sourcepub async fn delete_range(
&mut self,
values: &[Value],
range: KeyRange,
) -> Result<i64, IndexedDBError>
pub async fn delete_range( &mut self, values: &[Value], range: KeyRange, ) -> Result<i64, IndexedDBError>
Deletes rows that match values and range and returns the delete count.
Sourcepub async fn open_cursor(
&mut self,
values: &[Value],
range: Option<KeyRange>,
direction: CursorDirection,
) -> Result<Cursor, IndexedDBError>
pub async fn open_cursor( &mut self, values: &[Value], range: Option<KeyRange>, direction: CursorDirection, ) -> Result<Cursor, IndexedDBError>
Opens a full-value cursor over the secondary index.
Sourcepub async fn open_key_cursor(
&mut self,
values: &[Value],
range: Option<KeyRange>,
direction: CursorDirection,
) -> Result<Cursor, IndexedDBError>
pub async fn open_key_cursor( &mut self, values: &[Value], range: Option<KeyRange>, direction: CursorDirection, ) -> Result<Cursor, IndexedDBError>
Opens a key-only cursor over the secondary index.