pub trait TransactionIndexApi: Send {
// Required methods
fn get<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
) -> Pin<Box<dyn Future<Output = Result<Record, IndexedDBError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn get_key<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
) -> Pin<Box<dyn Future<Output = Result<String, IndexedDBError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn get_all<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
range: Option<KeyRange>,
) -> Pin<Box<dyn Future<Output = Result<Vec<Record>, IndexedDBError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn get_all_keys<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
range: Option<KeyRange>,
) -> Pin<Box<dyn Future<Output = Result<Vec<String>, IndexedDBError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn count<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
range: Option<KeyRange>,
) -> Pin<Box<dyn Future<Output = Result<i64, IndexedDBError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn delete<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
) -> Pin<Box<dyn Future<Output = Result<i64, IndexedDBError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn delete_range<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
range: KeyRange,
) -> Pin<Box<dyn Future<Output = Result<i64, IndexedDBError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Expand description
Fakeable transaction-scoped secondary-index contract.
Required Methods
Sourcefn get<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
) -> Pin<Box<dyn Future<Output = Result<Record, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
) -> Pin<Box<dyn Future<Output = Result<Record, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Loads the first row that matches values inside the transaction.
Sourcefn get_key<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
) -> Pin<Box<dyn Future<Output = Result<String, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_key<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
) -> Pin<Box<dyn Future<Output = Result<String, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Resolves the primary key for the first matching row inside the transaction.
Sourcefn get_all<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
range: Option<KeyRange>,
) -> Pin<Box<dyn Future<Output = Result<Vec<Record>, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_all<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
range: Option<KeyRange>,
) -> Pin<Box<dyn Future<Output = Result<Vec<Record>, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Loads every row that matches values and range inside the transaction.
Sourcefn get_all_keys<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
range: Option<KeyRange>,
) -> Pin<Box<dyn Future<Output = Result<Vec<String>, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_all_keys<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
range: Option<KeyRange>,
) -> Pin<Box<dyn Future<Output = Result<Vec<String>, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Loads every primary key that matches values and range inside the transaction.
Sourcefn count<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
range: Option<KeyRange>,
) -> Pin<Box<dyn Future<Output = Result<i64, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn count<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
range: Option<KeyRange>,
) -> Pin<Box<dyn Future<Output = Result<i64, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Counts rows that match values and range inside the transaction.
Sourcefn delete<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
) -> Pin<Box<dyn Future<Output = Result<i64, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn delete<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
) -> Pin<Box<dyn Future<Output = Result<i64, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Deletes rows that match values inside the transaction.
Sourcefn delete_range<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
range: KeyRange,
) -> Pin<Box<dyn Future<Output = Result<i64, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn delete_range<'life0, 'life1, 'async_trait>(
&'life0 mut self,
values: &'life1 [Value],
range: KeyRange,
) -> Pin<Box<dyn Future<Output = Result<i64, IndexedDBError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Deletes rows that match values and range inside the transaction.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".